# eric7.Plugins.CheckerPlugins.CodeStyleChecker.Security.Checks.tryExcept

Module implementing checks for insecure except blocks.

### Global Attributes

None

### Classes

None

### Functions

checkTryExceptContinue | Function to check for a continue in the except block.
checkTryExceptPass | Function to check for a pass in the except block.
getChecks | Public method to get a dictionary with checks handled by this module.

## checkTryExceptContinue

checkTryExceptContinue(reportError, context, config)

Function to check for a continue in the except block.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## checkTryExceptPass

checkTryExceptPass(reportError, context, config)

Function to check for a pass in the except block.

reportError (func)
  function to be used to report errors
context (SecurityContext)
  security context object
config (dict)
  dictionary with configuration data

Up

## getChecks

getChecks()

Public method to get a dictionary with checks handled by this module.

Return:
  dictionary containing checker lists containing checker function and list of codes

Return Type:
  dict

Up